@@ -41,6 +41,8 @@
 
 #define KGLOBALACCELPRIVATE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KGLOBALACCELPRIVATE_NO_DEPRECATED) && !defined(KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54200
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x54200
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KGLOBALACCELPRIVATE_DEPRECATED
-#  define KGLOBALACCELPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KGLOBALACCELPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KGLOBALACCELPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -113,22 +115,7 @@
 #else
 #  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_3(text)
 #endif
-
-#if KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
-#  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_90(text) KGLOBALACCELPRIVATE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_90(text)
-#endif
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_##minor(text)
-#define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION(major, minor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KGLOBALACCELPRIVATE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION(major, minor, text)
-#  define KGLOBALACCELPRIVATE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KGLOBALACCELPRIVATE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KGLOBALACCELPRIVATE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KGLOBALACCELPRIVATE_EXPORT_H */
